// *********************************************************************
//                           Watchdog - part 2
//                             Demo example
// *********************************************************************
//
// Intended for:
//   HW: - TR-72G + DK-EVAL-04x development kit
//
//   OS: - v4.06G
//
// Description:
//   This example periodically sends an RF message and then goes to the
//   Sleep mode. The period equals the WDT timeout.
//   It cooperates with the first part of the Watchdog example - watchdog_alarm.c.
//
// ---------------------------------------------------------------------
// Online IQRF OS Reference Guide: https://doc.iqrf.org/IQRF-OS-Reference-guide
//
// Copyright (c) IQRF Tech s.r.o.
//
// File:    WATCHDOG_TX.c
// Version: v3.00                                   Revision: 17/06/2021
//
// Revision history:
//   v3.00: 17/06/2021  First release for TR-7xG.
//
// *********************************************************************
// Default IQRF include (modify the path according to your setup)
#include "IQRF.h"

// *********************************************************************
// EEPROM
#pragma packedCdataStrings 0 //12345678901234567890123456789012
#pragma cdata[__EEAPPINFO] =  "watchdog"

// *********************************************************************

void APPLICATION()
{
    setWDTon_4s();                      // WDT on, timeout 4 s (see IQRF-macros.h)
    pulsingLEDR();                      // 4x LED flash (boot indication)
    waitDelay(95);
    stopLEDR();
    
    appInfo();                          // Copy Application data
    copyBufferINFO2RF();                //  to buffer RF

    while (1)
    {
        clrwdt();
        iqrfSleep();                    // Wakeup on WDT every cca 4s

        pulseLEDR();                    // LED indication
        DLEN = 8;                       // Setup RF packet length
                                        //  (only 8 B of Application
                                        //  info to be sent)
        RFTXpacket();                   // Transmit the message
        waitDelay(5);                   // To finish pulseLED
    }
}
// *********************************************************************

